@@ -5,7 +5,7 @@ use Mojo::Collection 'c';
 use DBI;
 use Carp qw(croak);
   
-our $VERSION  = '0.05';
+our $VERSION  = '0.06';
 
 sub new {
 	my $class = shift;
@@ -125,8 +125,8 @@ sub move {
 
 	croak "Impossible to transfer to itself or children" if($id eq $target_id);
 
-	my $path        = $get_id->{'path'};
-	my $path_target = $get_target_id->{'path'};
+	my $path        = $get_id->{$column_path};
+	my $path_target = $get_target_id->{$column_path};
 	croak "Impossible to transfer to itself or children" if($path =~ m/^$path_target/);
 
 	my $length = $self->{'length'};
